import { Widget } from '@lumino/widgets';
import moment from 'moment';
import { generateNode } from '../../utils';
/**
 * Comment widget
 */
export class CommentWidget extends Widget {
    constructor(props) {
        const { comment, renderMime } = props;
        const markdownRenderer = renderMime.createRenderer('text/markdown');
        super({
            node: CommentWidget.createNode(comment, markdownRenderer)
        });
        this._markdownRenderer = markdownRenderer;
        this._markdownRenderer.renderModel({
            data: {
                'text/markdown': comment.text
            },
            trusted: false,
            metadata: {},
            setData: () => null
        });
    }
    /**
     * Create the HTML nodes
     *
     * @param comment Comment to be displayed
     * @param markdownRenderer Markdown renderer
     */
    static createNode(comment, markdownRenderer) {
        const head = generateNode('div', { class: 'jp-PullRequestCommentItem' });
        head
            .appendChild(generateNode('div', { class: 'jp-PullRequestCommentItemImg' }))
            .appendChild(generateNode('img', { src: comment.userPicture, altText: 'Avatar' }));
        const content = head.appendChild(generateNode('div', { class: 'jp-PullRequestCommentItemContent' }));
        const div = content.appendChild(generateNode('p', { class: 'jp-PullRequestCommentItemContentTitle' }));
        div.appendChild(generateNode('strong', null, comment.userName));
        div.appendChild(generateNode('span', {
            class: 'jp-PullRequestGrayedText',
            title: new Date(comment.updatedAt).toString()
        }, moment(comment.updatedAt).fromNow()));
        // Add rendered comment
        content.appendChild(markdownRenderer.node);
        return head;
    }
    /**
     * Dispose the widget
     */
    dispose() {
        if (this.isDisposed) {
            return;
        }
        this._markdownRenderer.dispose();
        super.dispose();
    }
}
//# sourceMappingURL=Comment.js.map